@@ -35,7 +35,10 @@
 #include <sys/filio.h>
 #endif
 
-SwooleGS_t *SwooleGS;
+swGlobal_t SwooleG;
+swGlobalS_t *SwooleGS;
+__thread swThreadGlobal_t SwooleTG;
+swWorkerGlobal_t SwooleWG;
 
 static void swoole_fatal_error(int code, const char *format, ...);
 
@@ -84,13 +87,13 @@ void swoole_init(void)
     SwooleG.memory_pool = swMemoryGlobal_new(SW_GLOBAL_MEMORY_PAGESIZE, 1);
     if (SwooleG.memory_pool == NULL)
     {
-        printf("[Master] Fatal Error: global memory allocation failure.");
+        printf("[Master] Fatal Error: global memory allocation failure");
         exit(1);
     }
-    SwooleGS = SwooleG.memory_pool->alloc(SwooleG.memory_pool, sizeof(SwooleGS_t));
+    SwooleGS = SwooleG.memory_pool->alloc(SwooleG.memory_pool, sizeof(swGlobalS_t));
     if (SwooleGS == NULL)
     {
-        printf("[Master] Fatal Error: failed to allocate memory for SwooleGS.");
+        printf("[Master] Fatal Error: failed to allocate memory for SwooleGS");
         exit(2);
     }
 
@@ -104,7 +107,7 @@ void swoole_init(void)
     struct rlimit rlmt;
     if (getrlimit(RLIMIT_NOFILE, &rlmt) < 0)
     {
-        swWarn("getrlimit() failed. Error: %s[%d]", strerror(errno), errno);
+        swSysWarn("getrlimit() failed");
     }
     else
     {
@@ -131,7 +134,7 @@ void swoole_init(void)
     //create tmp dir
     if (access(tmp_dir, R_OK) < 0 && swoole_mkdir_recursive(tmp_dir) < 0)
     {
-        swWarn("create task tmp dir(%s) failed.", tmp_dir);
+        swWarn("create task tmp dir(%s) failed", tmp_dir);
     }
     if (tmp_dir)
     {
@@ -172,7 +175,7 @@ pid_t swoole_fork()
 {
     if (swoole_coroutine_is_in())
     {
-        swError("must be forked outside the coroutine.");
+        swFatalError(SW_ERROR_OPERATION_NOT_SUPPORT, "must be forked outside the coroutine");
         return -1;
     }
     if (SwooleAIO.init)
@@ -196,7 +199,7 @@ pid_t swoole_fork()
         SwooleG.memory_pool = swMemoryGlobal_new(SW_GLOBAL_MEMORY_PAGESIZE, 1);
         if (SwooleG.memory_pool == NULL)
         {
-            printf("[Worker] Fatal Error: global memory allocation failure.");
+            printf("[Worker] Fatal Error: global memory allocation failure");
             exit(1);
         }
         /**
@@ -288,7 +291,7 @@ int swoole_mkdir_recursive(const char *dir)
 
     if (len + 1 > PATH_MAX) /* PATH_MAX limit includes string trailing null character */
     {
-        swWarn("mkdir(%s) failed. Path exceeds the limit of %d characters.", dir, PATH_MAX - 1);
+        swWarn("mkdir(%s) failed. Path exceeds the limit of %d characters", dir, PATH_MAX - 1);
         return -1;
     }
     strncpy(tmp, dir, PATH_MAX);
@@ -309,7 +312,7 @@ int swoole_mkdir_recursive(const char *dir)
             {
                 if (mkdir(tmp, 0755) == -1)
                 {
-                    swWarn("mkdir(%s) failed. Error: %s[%d]", tmp, strerror(errno), errno);
+                    swSysWarn("mkdir(%s) failed", tmp);
                     return -1;
                 }
             }
@@ -327,7 +330,7 @@ char* swoole_dirname(char *file)
     char *dirname = sw_strdup(file);
     if (dirname == NULL)
     {
-        swWarn("strdup() failed.");
+        swWarn("strdup() failed");
         return NULL;
     }
 
@@ -420,7 +423,7 @@ size_t swoole_sync_writefile(int fd, const void *data, size_t len)
             {
                 continue;
             }
-            swSysError("write(%d, %d) failed.", fd, towrite);
+            swSysWarn("write(%d, %d) failed", fd, towrite);
             break;
         }
     }
@@ -470,7 +473,7 @@ int swoole_system_random(int min, int max)
 
     if (read(dev_random_fd, next_random_byte, bytes_to_read) < bytes_to_read)
     {
-        swSysError("read() from /dev/urandom failed.");
+        swSysWarn("read() from /dev/urandom failed");
         return SW_ERR;
     }
     return min + (random_value % (max - min + 1));
@@ -480,11 +483,11 @@ void swoole_redirect_stdout(int new_fd)
 {
     if (dup2(new_fd, STDOUT_FILENO) < 0)
     {
-        swoole_error_log(SW_LOG_ERROR, SW_ERROR_SYSTEM_CALL_FAIL, "dup2(STDOUT_FILENO) failed. Error: %s[%d]", strerror(errno), errno);
+        swSysWarn("dup2(STDOUT_FILENO) failed");
     }
     if (dup2(new_fd, STDERR_FILENO) < 0)
     {
-        swoole_error_log(SW_LOG_ERROR, SW_ERROR_SYSTEM_CALL_FAIL, "dup2(STDERR_FILENO) failed. Error: %s[%d]", strerror(errno), errno);
+        swSysWarn("dup2(STDERR_FILENO) failed");
     }
 }
 
@@ -572,7 +575,7 @@ int swoole_tmpfile(char *filename)
 
     if (tmp_fd < 0)
     {
-        swSysError("mkstemp(%s) failed.", filename);
+        swSysWarn("mkstemp(%s) failed", filename);
         return SW_ERR;
     }
     else
@@ -601,7 +604,7 @@ long swoole_file_size(char *filename)
     struct stat file_stat;
     if (lstat(filename, &file_stat) < 0)
     {
-        swSysError("lstat(%s) failed.", filename);
+        swSysWarn("lstat(%s) failed", filename);
         SwooleG.error = errno;
         return -1;
     }
@@ -622,19 +625,19 @@ swString* swoole_file_get_contents(char *filename)
     }
     else if (filesize == 0)
     {
-        swoole_error_log(SW_LOG_TRACE, SW_ERROR_FILE_EMPTY, "file[%s] is empty.", filename);
+        swoole_error_log(SW_LOG_TRACE, SW_ERROR_FILE_EMPTY, "file[%s] is empty", filename);
         return NULL;
     }
     else if (filesize > SW_MAX_FILE_CONTENT)
     {
-        swoole_error_log(SW_LOG_WARNING, SW_ERROR_FILE_TOO_LARGE, "file[%s] is too large.", filename);
+        swoole_error_log(SW_LOG_WARNING, SW_ERROR_FILE_TOO_LARGE, "file[%s] is too large", filename);
         return NULL;
     }
 
     int fd = open(filename, O_RDONLY);
     if (fd < 0)
     {
-        swWarn("open(%s) failed. Error: %s[%d]", filename, strerror(errno), errno);
+        swSysWarn("open(%s) failed", filename);
         return NULL;
     }
     swString *content = swString_new(filesize);
@@ -658,7 +661,7 @@ swString* swoole_file_get_contents(char *filename)
             }
             else
             {
-                swSysError("pread(%d, %ld, %d) failed.", fd, filesize - readn, readn);
+                swSysWarn("pread(%d, %ld, %d) failed", fd, filesize - readn, readn);
                 swString_free(content);
                 close(fd);
                 return NULL;
@@ -675,19 +678,19 @@ int swoole_file_put_contents(char *filename, char *content, size_t length)
 {
     if (length <= 0)
     {
-        swoole_error_log(SW_LOG_TRACE, SW_ERROR_FILE_EMPTY, "content is empty.");
+        swoole_error_log(SW_LOG_TRACE, SW_ERROR_FILE_EMPTY, "content is empty");
         return SW_ERR;
     }
     if (length > SW_MAX_FILE_CONTENT)
     {
-        swoole_error_log(SW_LOG_WARNING, SW_ERROR_FILE_TOO_LARGE, "content is too large.");
+        swoole_error_log(SW_LOG_WARNING, SW_ERROR_FILE_TOO_LARGE, "content is too large");
         return SW_ERR;
     }
 
     int fd = open(filename, O_WRONLY | O_TRUNC | O_CREAT, 0666);
     if (fd < 0)
     {
-        swSysError("open(%s) failed.", filename);
+        swSysWarn("open(%s) failed", filename);
         return SW_ERR;
     }
 
@@ -709,7 +712,7 @@ int swoole_file_put_contents(char *filename, char *content, size_t length)
             }
             else
             {
-                swSysError("write(%d, %d) failed.", fd, chunk_size);
+                swSysWarn("write(%d, %d) failed", fd, chunk_size);
                 close(fd);
                 return -1;
             }
@@ -749,7 +752,7 @@ size_t swoole_sync_readfile(int fd, void *buf, size_t len)
             {
                 continue;
             }
-            swWarn("read() failed. Error: %s[%d]", strerror(errno), errno);
+            swSysWarn("read() failed");
             break;
         }
     }
@@ -758,7 +761,7 @@ size_t swoole_sync_readfile(int fd, void *buf, size_t len)
 
 swString* swoole_sync_readfile_eof(int fd)
 {
-    int n = 0;
+    ssize_t n = 0;
     swString *data = swString_new(SW_BUFFER_SIZE_STD);
     if (data == NULL)
     {
@@ -774,11 +777,10 @@ swString* swoole_sync_readfile_eof(int fd)
         }
         else
         {
-            if (swString_extend(data, data->size * 2) < 0)
+            if (swString_grow(data, (size_t) n))
             {
                 return data;
             }
-            data->length += n;
         }
     }
     return data;
@@ -880,7 +882,7 @@ void swoole_ioctl_set_block(int sock, int nonblock)
 
     if (ret < 0)
     {
-        swSysError("ioctl(%d, FIONBIO, %d) failed.", sock, nonblock);
+        swSysWarn("ioctl(%d, FIONBIO, %d) failed", sock, nonblock);
     }
 }
 
@@ -898,7 +900,7 @@ void swoole_fcntl_set_option(int sock, int nonblock, int cloexec)
 
         if (opts < 0)
         {
-            swSysError("fcntl(%d, GETFL) failed.", sock);
+            swSysWarn("fcntl(%d, GETFL) failed", sock);
         }
 
         if (nonblock)
@@ -918,7 +920,7 @@ void swoole_fcntl_set_option(int sock, int nonblock, int cloexec)
 
         if (ret < 0)
         {
-            swSysError("fcntl(%d, SETFL, opts) failed.", sock);
+            swSysWarn("fcntl(%d, SETFL, opts) failed", sock);
         }
     }
 
@@ -933,7 +935,7 @@ void swoole_fcntl_set_option(int sock, int nonblock, int cloexec)
 
         if (opts < 0)
         {
-            swSysError("fcntl(%d, GETFL) failed.", sock);
+            swSysWarn("fcntl(%d, GETFL) failed", sock);
         }
 
         if (cloexec)
@@ -953,7 +955,7 @@ void swoole_fcntl_set_option(int sock, int nonblock, int cloexec)
 
         if (ret < 0)
         {
-            swSysError("fcntl(%d, SETFD, opts) failed.", sock);
+            swSysWarn("fcntl(%d, SETFD, opts) failed", sock);
         }
     }
 #endif
@@ -1223,7 +1225,7 @@ int swoole_getaddrinfo(swRequest_getaddrinfo *req)
             memcpy((char *) buffer + (i * sizeof(struct sockaddr_in6)), ptr->ai_addr, sizeof(struct sockaddr_in6));
             break;
         default:
-            swWarn("unknown socket family[%d].", ptr->ai_family);
+            swWarn("unknown socket family[%d]", ptr->ai_family);
             break;
         }
         i++;
@@ -1250,7 +1252,7 @@ SW_API int swoole_add_function(const char *name, void* func)
     }
     if (swHashMap_find(SwooleG.functions, (char *) name, strlen(name)) != NULL)
     {
-        swWarn("Function '%s' has already been added.", name);
+        swWarn("Function '%s' has already been added", name);
         return SW_ERR;
     }
     return swHashMap_add(SwooleG.functions, (char *) name, strlen(name), func);
@@ -1310,7 +1312,7 @@ int swoole_shell_exec(const char *command, pid_t *pid, uint8_t get_error_stream)
 
     if ((child_pid = fork()) == -1)
     {
-        swSysError("fork() failed.");
+        swSysWarn("fork() failed");
         close(fds[0]);
         close(fds[1]);
         return SW_ERR;
@@ -1420,11 +1422,11 @@ static void swoole_fatal_error(int code, const char *format, ...)
     size_t retval = 0;
     va_list args;
 
+    SwooleGS->lock_2.lock(&SwooleGS->lock_2);
     retval += sw_snprintf(sw_error, SW_ERROR_MSG_SIZE, "(ERROR %d): ", code);
     va_start(args, format);
     retval += sw_vsnprintf(sw_error + retval, SW_ERROR_MSG_SIZE - retval, format, args);
     va_end(args);
-    SwooleGS->lock_2.lock(&SwooleGS->lock_2);
     SwooleG.write_log(SW_LOG_ERROR, sw_error, retval);
     SwooleGS->lock_2.unlock(&SwooleGS->lock_2);
     exit(255);
