@@ -15,6 +15,7 @@
 */
 
 #include "coroutine.h"
+#include "coroutine_c_api.h"
 #include "async.h"
 
 using namespace swoole;
@@ -83,7 +84,7 @@ void Coroutine::close()
         on_close(task);
     }
 #ifndef SW_NO_USE_ASM_CONTEXT
-    swTraceLog(SW_TRACE_CONTEXT, "coroutine#%ld stack memory use less than %ld bytes.", get_cid(), ctx.get_stack_usage());
+    swTraceLog(SW_TRACE_CONTEXT, "coroutine#%ld stack memory use less than %ld bytes", get_cid(), ctx.get_stack_usage());
 #endif
     current = origin;
     coroutines.erase(cid);
@@ -131,17 +132,10 @@ void Coroutine::set_on_close(coro_php_close_t func)
     on_close = func;
 }
 
-
-extern "C"
-{
-/**
- * for C
- */
 uint8_t swoole_coroutine_is_in()
 {
     return !!Coroutine::get_current();
 }
-}
 
 /**
  * for gdb
