@@ -664,7 +664,10 @@ bool Socket::connect(string _host, int _port, int flags)
                     ssl_host_name = host;
                 }
 #endif
+                /* locked like wait_event */
+                read_co = write_co = Coroutine::get_current_safe();
                 host = Coroutine::gethostbyname(host, AF_INET, connect_timeout);
+                read_co = write_co = nullptr;
                 if (host.empty())
                 {
                     set_err(SwooleG.error);
@@ -692,7 +695,10 @@ bool Socket::connect(string _host, int _port, int flags)
                     ssl_host_name = host;
                 }
 #endif
+                /* locked like wait_event */
+                read_co = write_co = Coroutine::get_current_safe();
                 host = Coroutine::gethostbyname(host, AF_INET6, connect_timeout);
+                read_co = write_co = nullptr;
                 if (host.empty())
                 {
                     set_err(SwooleG.error);
@@ -1132,6 +1138,9 @@ bool Socket::ssl_handshake()
     {
         return false;
     }
+#ifdef SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER
+    SSL_set_mode(socket->ssl, SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
+#endif
 #ifdef SSL_CTRL_SET_TLSEXT_HOSTNAME
     if (ssl_option.tls_host_name)
     {
