@@ -327,7 +327,7 @@ static int swReactorKqueue_wait(swReactor *reactor, struct timeval *timeo)
             }
             else
             {
-                continue;
+                goto _continue;
             }
         }
         else if (n == 0)
@@ -394,7 +394,7 @@ static int swReactorKqueue_wait(swReactor *reactor, struct timeval *timeo)
             }
         }
 
-        if (reactor->onFinish != NULL)
+        _continue: if (reactor->onFinish != NULL)
         {
             reactor->onFinish(reactor);
         }
