@@ -26,7 +26,6 @@ static int swPort_onRead_check_length(swReactor *reactor, swListenPort *lp, swEv
 static int swPort_onRead_check_eof(swReactor *reactor, swListenPort *lp, swEvent *event);
 static int swPort_onRead_http(swReactor *reactor, swListenPort *lp, swEvent *event);
 static int swPort_onRead_redis(swReactor *reactor, swListenPort *lp, swEvent *event);
-static int swPort_http_static_handler(swServer *serv, swHttpRequest *request, swConnection *conn);
 
 void swPort_init(swListenPort *port)
 {
@@ -58,20 +57,20 @@ int swPort_enable_ssl_encrypt(swListenPort *ls)
 {
     if (ls->ssl_option.cert_file == NULL || ls->ssl_option.key_file == NULL)
     {
-        swWarn("SSL error, require ssl_cert_file and ssl_key_file.");
+        swWarn("SSL error, require ssl_cert_file and ssl_key_file");
         return SW_ERR;
     }
     ls->ssl_context = swSSL_get_context(&ls->ssl_option);
     if (ls->ssl_context == NULL)
     {
-        swWarn("swSSL_get_context() error.");
+        swWarn("swSSL_get_context() error");
         return SW_ERR;
     }
     if (ls->ssl_option.client_cert_file
             && swSSL_set_client_certificate(ls->ssl_context, ls->ssl_option.client_cert_file,
                     ls->ssl_option.verify_depth) == SW_ERR)
     {
-        swWarn("swSSL_set_client_certificate() error.");
+        swWarn("swSSL_set_client_certificate() error");
         return SW_ERR;
     }
     if (ls->open_http_protocol)
@@ -85,7 +84,7 @@ int swPort_enable_ssl_encrypt(swListenPort *ls)
     }
     if (swSSL_server_set_cipher(ls->ssl_context, &ls->ssl_config) < 0)
     {
-        swWarn("swSSL_server_set_cipher() error.");
+        swWarn("swSSL_server_set_cipher() error");
         return SW_ERR;
     }
     return SW_OK;
@@ -100,7 +99,7 @@ int swPort_listen(swListenPort *ls)
     //listen stream socket
     if (listen(sock, ls->backlog) < 0)
     {
-        swWarn("listen(%s:%d, %d) failed. Error: %s[%d]", ls->host, ls->port, ls->backlog, strerror(errno), errno);
+        swSysWarn("listen(%s:%d, %d) failed", ls->host, ls->port, ls->backlog);
         return SW_ERR;
     }
 
@@ -109,7 +108,7 @@ int swPort_listen(swListenPort *ls)
     {
         if (setsockopt(sock, IPPROTO_TCP, TCP_DEFER_ACCEPT, (const void*) &ls->tcp_defer_accept, sizeof(int)) != 0)
         {
-            swSysError("setsockopt(TCP_DEFER_ACCEPT) failed.");
+            swSysWarn("setsockopt(TCP_DEFER_ACCEPT) failed");
         }
     }
 #endif
@@ -119,7 +118,7 @@ int swPort_listen(swListenPort *ls)
     {
         if (setsockopt(sock, IPPROTO_TCP, TCP_FASTOPEN, (const void*) &ls->tcp_fastopen, sizeof(int)) != 0)
         {
-            swSysError("setsockopt(TCP_FASTOPEN) failed.");
+            swSysWarn("setsockopt(TCP_FASTOPEN) failed");
         }
     }
 #endif
@@ -129,7 +128,7 @@ int swPort_listen(swListenPort *ls)
     {
         if (setsockopt(sock, SOL_SOCKET, SO_KEEPALIVE, (void *) &option, sizeof(option)) != 0)
         {
-            swSysError("setsockopt(SO_KEEPALIVE) failed.");
+            swSysWarn("setsockopt(SO_KEEPALIVE) failed");
         }
 #ifdef TCP_KEEPIDLE
         setsockopt(sock, IPPROTO_TCP, TCP_KEEPIDLE, (void*) &ls->tcp_keepidle, sizeof(int));
@@ -235,7 +234,7 @@ static int swPort_onRead_raw(swReactor *reactor, swListenPort *port, swEvent *ev
         switch (swConnection_error(errno))
         {
         case SW_ERROR:
-            swSysError("recv from connection#%d failed.", event->fd);
+            swSysWarn("recv from connection#%d failed", event->fd);
             return SW_OK;
         case SW_CLOSE:
             conn->close_errno = errno;
@@ -345,7 +344,7 @@ static int swPort_onRead_http(swReactor *reactor, swListenPort *port, swEvent *e
         switch (swConnection_error(errno))
         {
         case SW_ERROR:
-            swSysError("recv from connection#%d failed.", event->fd);
+            swSysWarn("recv from connection#%d failed", event->fd);
             return SW_OK;
         case SW_CLOSE:
             conn->close_errno = errno;
@@ -372,7 +371,7 @@ static int swPort_onRead_http(swReactor *reactor, swListenPort *port, swEvent *e
             {
                 return SW_OK;
             }
-            swoole_error_log(SW_LOG_TRACE, SW_ERROR_HTTP_INVALID_PROTOCOL, "get protocol failed.");
+            swoole_error_log(SW_LOG_TRACE, SW_ERROR_HTTP_INVALID_PROTOCOL, "get protocol failed");
 #ifdef SW_USE_HTTP2
             _bad_request:
 #endif
@@ -420,7 +419,7 @@ static int swPort_onRead_http(swReactor *reactor, swListenPort *port, swEvent *e
             {
                 if (buffer->size == buffer->length)
                 {
-                    swWarn("[2]http header is too long.");
+                    swWarn("[2]http header is too long");
                     goto close_fd;
                 }
                 else
@@ -443,7 +442,7 @@ static int swPort_onRead_http(swReactor *reactor, swListenPort *port, swEvent *e
                     /**
                      * send static file content directly in the reactor thread
                      */
-                    if (!(serv->enable_static_handler && swPort_http_static_handler(serv, request, conn)))
+                    if (!(serv->enable_static_handler && swHttp_static_handler(serv, request, conn)))
                     {
                         /**
                          * dynamic request, dispatch to worker
@@ -464,7 +463,7 @@ static int swPort_onRead_http(swReactor *reactor, swListenPort *port, swEvent *e
                 }
                 else if (buffer->size == buffer->length)
                 {
-                    swWarn("[0]http header is too long.");
+                    swWarn("[0]http header is too long");
                     goto close_fd;
                 }
                 /* wait more data */
@@ -475,7 +474,7 @@ static int swPort_onRead_http(swReactor *reactor, swListenPort *port, swEvent *e
             }
             else if (request->content_length > (protocol->package_max_length - request->header_length))
             {
-                swWarn("Content-Length is too big, MaxSize=[%d].", protocol->package_max_length - request->header_length);
+                swWarn("Content-Length is too big, MaxSize=[%d]", protocol->package_max_length - request->header_length);
                 goto close_fd;
             }
         }
@@ -607,214 +606,3 @@ void swPort_free(swListenPort *port)
     }
 }
 
-static int swPort_http_static_handler(swServer *serv, swHttpRequest *request, swConnection *conn)
-{
-    char *url = request->buffer->str + request->url_offset;
-    char *params = memchr(url, '?', request->url_length);
-
-    struct
-    {
-        off_t offset;
-        size_t length;
-        char filename[PATH_MAX];
-    } buffer;
-
-    char *p = buffer.filename;
-
-    memcpy(p, serv->document_root, serv->document_root_len);
-    p += serv->document_root_len;
-    size_t n = params ? params - url : request->url_length;
-
-    if (serv->document_root_len + n >= PATH_MAX)
-    {
-        return SW_FALSE;
-    }
-
-    memcpy(p, url, n);
-    p += n;
-    *p = '\0';
-
-    char real_path[PATH_MAX];
-    if (!realpath(buffer.filename, real_path))
-    {
-        return SW_FALSE;
-    }
-
-    if (real_path[serv->document_root_len] != '/')
-    {
-        return SW_FALSE;
-    }
-
-    if (strncmp(real_path, serv->document_root, serv->document_root_len) != 0)
-    {
-        return SW_FALSE;
-    }
-
-    struct stat file_stat;
-    if (lstat(buffer.filename, &file_stat) < 0)
-    {
-        return SW_FALSE;
-    }
-    if (file_stat.st_size == 0)
-    {
-        return SW_FALSE;
-    }
-    if ((file_stat.st_mode & S_IFMT) != S_IFREG)
-    {
-        return SW_FALSE;
-    }
-
-    char header_buffer[1024];
-    swSendData response;
-    response.info.fd = conn->session_id;
-
-    response.info.type = SW_EVENT_TCP;
-
-    p = request->buffer->str + request->url_offset + request->url_length + 10;
-    char *pe = request->buffer->str + request->header_length;
-
-    char *date_if_modified_since = NULL;
-    int length_if_modified_since = 0;
-
-    int state = 0;
-    for (; p < pe; p++)
-    {
-        switch(state)
-        {
-        case 0:
-            if (strncasecmp(p, SW_STRL("If-Modified-Since")) == 0)
-            {
-                p += sizeof("If-Modified-Since");
-                state = 1;
-            }
-            break;
-        case 1:
-            if (!isspace(*p))
-            {
-                date_if_modified_since = p;
-                state = 2;
-            }
-            break;
-        case 2:
-            if (strncasecmp(p, SW_STRL("\r\n")) == 0)
-            {
-                length_if_modified_since = p - date_if_modified_since;
-                goto check_modify_date;
-            }
-            break;
-        default:
-            break;
-        }
-    }
-
-    char date_[64];
-    struct tm *tm1;
-
-    check_modify_date: tm1 = gmtime(&serv->gs->now);
-    strftime(date_, sizeof(date_), "%a, %d %b %Y %H:%M:%S %Z", tm1);
-
-    char date_last_modified[64];
-#ifdef __MACH__
-    time_t file_mtime = file_stat.st_mtimespec.tv_sec;
-#elif defined(_WIN32)
-	time_t file_mtime = file_stat.st_mtime;
-#else
-    time_t file_mtime = file_stat.st_mtim.tv_sec;
-#endif
-
-    struct tm *tm2 = gmtime(&file_mtime);
-    strftime(date_last_modified, sizeof(date_last_modified), "%a, %d %b %Y %H:%M:%S %Z", tm2);
-
-    if (state == 2)
-    {
-        struct tm tm3;
-        char date_tmp[64];
-        memcpy(date_tmp, date_if_modified_since, length_if_modified_since);
-        date_tmp[length_if_modified_since] = 0;
-
-        char *date_format = NULL;
-
-        if (strptime(date_tmp, SW_HTTP_RFC1123_DATE_GMT, &tm3) != NULL)
-        {
-            date_format = SW_HTTP_RFC1123_DATE_GMT;
-        }
-        else if (strptime(date_tmp, SW_HTTP_RFC1123_DATE_UTC, &tm3) != NULL)
-        {
-            date_format = SW_HTTP_RFC1123_DATE_UTC;
-        }
-        else if (strptime(date_tmp, SW_HTTP_RFC850_DATE, &tm3) != NULL)
-        {
-            date_format = SW_HTTP_RFC850_DATE;
-        }
-        else if (strptime(date_tmp, SW_HTTP_ASCTIME_DATE, &tm3) != NULL)
-        {
-            date_format = SW_HTTP_ASCTIME_DATE;
-        }
-        if (date_format && mktime(&tm3) - (int) timezone >= file_mtime)
-        {
-            response.length = response.info.len = sw_snprintf(header_buffer, sizeof(header_buffer),
-                    "HTTP/1.1 304 Not Modified\r\n"
-                    "%s"
-                    "Date: %s\r\n"
-                    "Last-Modified: %s\r\n"
-                    "Server: %s\r\n\r\n",
-                    request->keep_alive ? "Connection: keep-alive\r\n" : "",
-                    date_,
-                    date_last_modified,
-                    SW_HTTP_SERVER_SOFTWARE
-            );
-            response.data = header_buffer;
-            swServer_master_send(serv, &response);
-            goto _finish;
-        }
-    }
-
-    response.length = response.info.len = sw_snprintf(header_buffer, sizeof(header_buffer),
-            "HTTP/1.1 200 OK\r\n"
-            "%s"
-            "Content-Length: %ld\r\n"
-            "Content-Type: %s\r\n"
-            "Date: %s\r\n"
-            "Last-Modified: %s\r\n"
-            "Server: %s\r\n\r\n",
-            request->keep_alive ? "Connection: keep-alive\r\n" : "",
-            (long) file_stat.st_size,
-            swoole_get_mime_type(buffer.filename),
-            date_,
-            date_last_modified,
-            SW_HTTP_SERVER_SOFTWARE);
-
-    response.data = header_buffer;
-
-#ifdef HAVE_TCP_NOPUSH
-    if (conn->tcp_nopush == 0)
-    {
-        if (swSocket_tcp_nopush(conn->fd, 1) == -1)
-        {
-            swWarn("swSocket_tcp_nopush() failed. Error: %s[%d]", strerror(errno), errno);
-        }
-        conn->tcp_nopush = 1;
-    }
-#endif
-    swServer_master_send(serv, &response);
-
-    buffer.offset = 0;
-    buffer.length = file_stat.st_size;
-
-    response.info.type = SW_EVENT_SENDFILE;
-    response.length = response.info.len = sizeof(swSendFile_request) + buffer.length + 1;
-    response.data = (void*) &buffer;
-
-    swServer_master_send(serv, &response);
-
-    _finish:
-    if (!request->keep_alive)
-    {
-        response.info.type = SW_EVENT_CLOSE;
-        response.length = 0;
-        response.data = NULL;
-        swServer_master_send(serv, &response);
-    }
-
-    return SW_TRUE;
-}
