@@ -15,7 +15,7 @@
   +----------------------------------------------------------------------+
  */
 
-#include "php_swoole.h"
+#include "php_swoole_cxx.h"
 #include "swoole_coroutine.h"
 
 using namespace swoole;
@@ -26,6 +26,70 @@ bool PHPCoroutine::active = false;
 uint64_t PHPCoroutine::max_num = SW_DEFAULT_MAX_CORO_NUM;
 php_coro_task PHPCoroutine::main_task = {0};
 
+#ifdef SW_CORO_SCHEDULER_TICK
+int64_t PHPCoroutine::max_exec_msec = 0;
+user_opcode_handler_t PHPCoroutine::ori_tick_handler = NULL;
+
+inline void PHPCoroutine::interrupt_callback(void *data)
+{
+    Coroutine *co = (Coroutine *) data;
+    if (co && !co->is_end())
+    {
+        swTraceLog(SW_TRACE_COROUTINE, "interrupt_callback cid=%ld ", co->get_cid());
+        co->resume();
+    }
+}
+
+inline void PHPCoroutine::tick(uint32_t tick_count)
+{
+    php_coro_task *task = PHPCoroutine::get_task();
+    if (task && task->co && tick_count > 0 && is_schedulable(task))
+    {
+        SwooleG.main_reactor->defer(SwooleG.main_reactor, interrupt_callback, (void *) task->co);
+        task->co->yield();
+    }
+}
+
+inline int PHPCoroutine::tick_handler(zend_execute_data *execute_data)
+{
+    if (SW_CORO_SCHEDULER_TICK_EXPECT(max_exec_msec > 0))
+    {
+        uint32_t tick_count = execute_data->opline->extended_value;
+        if ((uint32_t) ++EG(ticks_count) >= tick_count)
+        {
+            EG(ticks_count) = 0;
+            tick(tick_count);
+        }
+    }
+    execute_data->opline++;
+    return ZEND_USER_OPCODE_CONTINUE;
+}
+
+void PHPCoroutine::enable_scheduler_tick()
+{
+    ori_tick_handler = zend_get_user_opcode_handler(ZEND_TICKS);
+    if (!ori_tick_handler)
+    {
+        zend_set_user_opcode_handler(ZEND_TICKS, tick_handler);
+    }
+}
+
+void PHPCoroutine::disable_scheduler_tick()
+{
+    zend_set_user_opcode_handler(ZEND_TICKS, ori_tick_handler ? ori_tick_handler : NULL);
+}
+#endif
+
+void PHPCoroutine::init()
+{
+    Coroutine::set_on_yield(on_yield);
+    Coroutine::set_on_resume(on_resume);
+    Coroutine::set_on_close(on_close);
+#ifdef SW_CORO_SCHEDULER_TICK
+    enable_scheduler_tick();
+#endif
+}
+
 inline void PHPCoroutine::vm_stack_init(void)
 {
     uint32_t size = SW_DEFAULT_PHP_STACK_PAGE_SIZE;
@@ -81,6 +145,9 @@ inline void PHPCoroutine::save_vm_stack(php_coro_task *task)
     task->exception_class = EG(exception_class);
     task->exception = EG(exception);
     SW_SAVE_EG_SCOPE(task->scope);
+#ifdef SW_CORO_SCHEDULER_TICK
+    task->ticks_count = EG(ticks_count);
+#endif
 }
 
 inline void PHPCoroutine::restore_vm_stack(php_coro_task *task)
@@ -99,6 +166,9 @@ inline void PHPCoroutine::restore_vm_stack(php_coro_task *task)
     EG(exception_class) = task->exception_class;
     EG(exception) = task->exception;
     SW_SET_EG_SCOPE(task->scope);
+#ifdef SW_CORO_SCHEDULER_TICK
+    EG(ticks_count) = task->ticks_count;
+#endif
 }
 
 inline void PHPCoroutine::save_og(php_coro_task *task)
@@ -152,6 +222,9 @@ void PHPCoroutine::on_resume(void *arg)
     php_coro_task *current_task = get_task();
     save_task(current_task);
     restore_task(task);
+#ifdef SW_CORO_SCHEDULER_TICK
+    record_last_msec(task);
+#endif
     swTraceLog(SW_TRACE_COROUTINE,"php_coro_resume from cid=%ld to cid=%ld", Coroutine::get_current_cid(), task->co->get_cid());
 }
 
@@ -208,10 +281,26 @@ void PHPCoroutine::create_func(void *arg)
     call = (zend_execute_data *) (EG(vm_stack_top));
     task = (php_coro_task *) EG(vm_stack_top);
     EG(vm_stack_top) = (zval *) ((char *) call + PHP_CORO_TASK_SLOT * sizeof(zval));
+
+#if PHP_VERSION_ID < 70400
     call = zend_vm_stack_push_call_frame(
         ZEND_CALL_TOP_FUNCTION | ZEND_CALL_ALLOCATED,
         func, argc, fci_cache.called_scope, fci_cache.object
     );
+#else
+    do {
+        uint32_t call_info;
+        void *object_or_called_scope;
+        if ((func->common.fn_flags & ZEND_ACC_STATIC) || !fci_cache.object) {
+            object_or_called_scope = fci_cache.called_scope;
+            call_info = ZEND_CALL_TOP_FUNCTION | ZEND_CALL_DYNAMIC;
+        } else {
+            object_or_called_scope = fci_cache.object;
+            call_info = ZEND_CALL_TOP_FUNCTION | ZEND_CALL_DYNAMIC | ZEND_CALL_HAS_THIS;
+        }
+        call = zend_vm_stack_push_call_frame(call_info, func, argc, object_or_called_scope);
+    } while (0);
+#endif
 
     SW_SET_EG_SCOPE(func->common.scope);
 
@@ -253,6 +342,9 @@ void PHPCoroutine::create_func(void *arg)
     task->defer_tasks = nullptr;
     task->pcid = task->co->get_origin_cid();
     task->context = nullptr;
+#ifdef SW_CORO_SCHEDULER_TICK
+    record_last_msec(task);
+#endif
 
     swTraceLog(
         SW_TRACE_COROUTINE, "Create coro id: %ld, origin cid: %ld, coro total count: %zu, heap size: %zu",
@@ -296,7 +388,7 @@ void PHPCoroutine::create_func(void *arg)
             defer_fci->fci.params = retval;
             if (UNEXPECTED(sw_call_function_anyway(&defer_fci->fci, &defer_fci->fci_cache) == FAILURE))
             {
-                swoole_php_fatal_error(E_WARNING, "defer callback handler error.");
+                swoole_php_fatal_error(E_WARNING, "defer callback handler error");
             }
             sw_fci_cache_discard(&defer_fci->fci_cache);
             efree(defer_fci);
@@ -326,7 +418,7 @@ long PHPCoroutine::create(zend_fcall_info_cache *fci_cache, uint32_t argc, zval
 {
     if (unlikely(!active))
     {
-        if (zend_get_module_started("xdebug") == SUCCESS)
+        if (zend_hash_str_find_ptr(&module_registry, ZEND_STRL("xdebug")))
         {
             swoole_php_fatal_error(E_WARNING, "Using Xdebug in coroutines is extremely dangerous, please notice that it may lead to coredump!");
         }
@@ -336,18 +428,18 @@ long PHPCoroutine::create(zend_fcall_info_cache *fci_cache, uint32_t argc, zval
     }
     if (unlikely(Coroutine::count() >= max_num))
     {
-        swoole_php_fatal_error(E_WARNING, "exceed max number of coroutine %zu.", (uintmax_t) Coroutine::count());
+        swoole_php_fatal_error(E_WARNING, "exceed max number of coroutine %zu", (uintmax_t) Coroutine::count());
         return SW_CORO_ERR_LIMIT;
     }
     if (unlikely(!fci_cache || !fci_cache->function_handler))
     {
-        swoole_php_fatal_error(E_ERROR, "invalid function call info cache.");
+        swoole_php_fatal_error(E_ERROR, "invalid function call info cache");
         return SW_CORO_ERR_INVALID;
     }
     zend_uchar type = fci_cache->function_handler->type;
     if (unlikely(type != ZEND_USER_FUNCTION && type != ZEND_INTERNAL_FUNCTION))
     {
-        swoole_php_fatal_error(E_ERROR, "invalid function type %u.", fci_cache->function_handler->type);
+        swoole_php_fatal_error(E_ERROR, "invalid function type %u", fci_cache->function_handler->type);
         return SW_CORO_ERR_INVALID;
     }
 
@@ -370,21 +462,20 @@ void PHPCoroutine::defer(php_swoole_fci *fci)
     task->defer_tasks->push(fci);
 }
 
+/**
+ * Deprecated (should be removed after refactor MySQL and HTTP2 client)
+ */
 void PHPCoroutine::check_bind(const char *name, long bind_cid)
 {
     Coroutine::get_current_safe();
     if (unlikely(bind_cid > 0))
     {
-        swString *buffer = SwooleTG.buffer_stack;
-        swString_clear(buffer);
-        sw_get_debug_print_backtrace(buffer, DEBUG_BACKTRACE_IGNORE_ARGS, 3);
-        swoole_error_log(
-            SW_LOG_ERROR, SW_ERROR_CO_HAS_BEEN_BOUND,
+        swFatalError(
+            SW_ERROR_CO_HAS_BEEN_BOUND,
             "%s has already been bound to another coroutine#%ld, "
-            "reading or writing of the same socket in multiple coroutines at the same time is not allowed.\n"
-            "%.*s", name, bind_cid, (int) buffer->length, buffer->str
+            "reading or writing of the same socket in multiple coroutines at the same time is not allowed",
+            name, bind_cid
         );
-        exit(255);
     }
 }
 
