@@ -618,6 +618,8 @@ bool http_client::keep_liveness()
     {
         if (socket)
         {
+            /* in progress */
+            socket->check_bound(SW_EVENT_RDWR);
             zend_update_property_long(swoole_http_client_coro_ce, zobject, ZEND_STRL("errCode"), socket->errCode);
             zend_update_property_string(swoole_http_client_coro_ce, zobject, ZEND_STRL("errMsg"), socket->errMsg);
             zend_update_property_long(swoole_http_client_coro_ce, zobject, ZEND_STRL("statusCode"), HTTP_CLIENT_ESTATUS_SERVER_RESET);
@@ -641,6 +643,7 @@ bool http_client::send()
     char *method;
     uint32_t header_flag = 0x0;
     zval *zmethod, *zheaders, *zbody, *zupload_files, *zcookies, *z_download_file;
+    size_t send_bytes;
 
     if (uri.length() == 0)
     {
@@ -977,7 +980,8 @@ bool http_client::send()
             SW_HASHTABLE_FOREACH_END();
         }
 
-        if (socket->send_all(http_client_buffer->str, http_client_buffer->length) != (ssize_t) http_client_buffer->length)
+        send_bytes = http_client_buffer->length;
+        if (socket->send_all(http_client_buffer->str, http_client_buffer->length) != (ssize_t) send_bytes)
         {
             goto _send_fail;
         }
@@ -1042,7 +1046,9 @@ bool http_client::send()
                     swString_append_ptr(http_client_buffer, header_buf, n);
                     swString_append_ptr(http_client_buffer, Z_STRVAL_P(zcontent), Z_STRLEN_P(zcontent));
                     swString_append_ptr(http_client_buffer, "\r\n", 2);
-                    if (socket->send_all(http_client_buffer->str, http_client_buffer->length) != (ssize_t) http_client_buffer->length)
+
+                    send_bytes = http_client_buffer->length;
+                    if (socket->send_all(http_client_buffer->str, http_client_buffer->length) != (ssize_t) send_bytes)
                     {
                         goto _send_fail;
                     }
@@ -1127,7 +1133,8 @@ bool http_client::send()
         http_client_buffer->length, (int) http_client_buffer->length, http_client_buffer->str
     );
 
-    if (socket->send_all(http_client_buffer->str, http_client_buffer->length) != (ssize_t) http_client_buffer->length)
+    send_bytes = http_client_buffer->length;
+    if (socket->send_all(http_client_buffer->str, http_client_buffer->length) != (ssize_t) send_bytes)
     {
        _send_fail:
        zend_update_property_long(swoole_http_client_coro_ce, zobject, ZEND_STRL("errCode"), SwooleG.error = errno);
@@ -1332,7 +1339,8 @@ bool http_client::push(zval *zdata, zend_long opcode, bool fin)
         return false;
     }
 
-    if (socket->send_all(http_client_buffer->str, http_client_buffer->length) != (ssize_t) http_client_buffer->length)
+    size_t send_bytes = http_client_buffer->length;
+    if (socket->send_all(http_client_buffer->str, http_client_buffer->length) != (ssize_t) send_bytes)
     {
         zend_update_property_long(swoole_http_client_coro_ce, zobject, ZEND_STRL("errCode"), SwooleG.error = socket->errCode);
         zend_update_property_string(swoole_http_client_coro_ce, zobject, ZEND_STRL("errMsg"), strerror(SwooleG.error));
