@@ -69,14 +69,14 @@ static void free_signal_callback(void* data);
 
 static uint32_t php_swoole_worker_round_id = 0;
 static zval *signal_callback[SW_SIGNO_MAX];
-static zend_class_entry swoole_process_ce;
-zend_class_entry *swoole_process_ce_ptr;
+zend_class_entry *swoole_process_ce;
 static zend_object_handlers swoole_process_handlers;
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_process_construct, 0, 0, 1)
     ZEND_ARG_CALLABLE_INFO(0, callback, 0)
     ZEND_ARG_INFO(0, redirect_stdin_and_stdout)
     ZEND_ARG_INFO(0, pipe_type)
+    ZEND_ARG_INFO(0, enable_coroutine)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_process_void, 0, 0, 0)
@@ -189,30 +189,29 @@ static const zend_function_entry swoole_process_methods[] =
 
 void swoole_process_init(int module_number)
 {
-    SWOOLE_INIT_CLASS_ENTRY(swoole_process, "Swoole\\Process", "swoole_process", NULL, swoole_process_methods);
-    SWOOLE_SET_CLASS_SERIALIZABLE(swoole_process, zend_class_serialize_deny, zend_class_unserialize_deny);
-    SWOOLE_SET_CLASS_CLONEABLE(swoole_process, zend_class_clone_deny);
-    SWOOLE_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_process, zend_class_unset_property_deny);
+    SW_INIT_CLASS_ENTRY(swoole_process, "Swoole\\Process", "swoole_process", NULL, swoole_process_methods);
+    SW_SET_CLASS_SERIALIZABLE(swoole_process, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_CLONEABLE(swoole_process, zend_class_clone_deny);
+    SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_process, zend_class_unset_property_deny);
 
-    zend_declare_class_constant_long(swoole_process_ce_ptr, ZEND_STRL("IPC_NOWAIT"), MSGQUEUE_NOWAIT);
-    zend_declare_class_constant_long(swoole_process_ce_ptr, ZEND_STRL("PIPE_MASTER"), SW_PIPE_CLOSE_MASTER);
-    zend_declare_class_constant_long(swoole_process_ce_ptr, ZEND_STRL("PIPE_WORKER"), SW_PIPE_CLOSE_WORKER);
-    zend_declare_class_constant_long(swoole_process_ce_ptr, ZEND_STRL("PIPE_READ"), SW_PIPE_CLOSE_READ);
-    zend_declare_class_constant_long(swoole_process_ce_ptr, ZEND_STRL("PIPE_WRITE"), SW_PIPE_CLOSE_WRITE);
+    zend_declare_class_constant_long(swoole_process_ce, ZEND_STRL("IPC_NOWAIT"), MSGQUEUE_NOWAIT);
+    zend_declare_class_constant_long(swoole_process_ce, ZEND_STRL("PIPE_MASTER"), SW_PIPE_CLOSE_MASTER);
+    zend_declare_class_constant_long(swoole_process_ce, ZEND_STRL("PIPE_WORKER"), SW_PIPE_CLOSE_WORKER);
+    zend_declare_class_constant_long(swoole_process_ce, ZEND_STRL("PIPE_READ"), SW_PIPE_CLOSE_READ);
+    zend_declare_class_constant_long(swoole_process_ce, ZEND_STRL("PIPE_WRITE"), SW_PIPE_CLOSE_WRITE);
     bzero(signal_callback, sizeof(signal_callback));
 
-    zend_declare_property_null(swoole_process_ce_ptr, ZEND_STRL("pipe"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_process_ce_ptr, ZEND_STRL("callback"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_process_ce_ptr, ZEND_STRL("msgQueueId"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_process_ce_ptr, ZEND_STRL("msgQueueKey"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_process_ce_ptr, ZEND_STRL("pid"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_process_ce_ptr, ZEND_STRL("id"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_process_ce, ZEND_STRL("pipe"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_process_ce, ZEND_STRL("callback"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_process_ce, ZEND_STRL("msgQueueId"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_process_ce, ZEND_STRL("msgQueueKey"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_process_ce, ZEND_STRL("pid"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_process_ce, ZEND_STRL("id"), ZEND_ACC_PUBLIC);
 
     /**
      * 31 signal constants
      */
-    zval *zpcntl;
-    if (!(zpcntl = zend_hash_str_find(&module_registry, ZEND_STRL("pcntl"))))
+    if (!zend_hash_str_find(&module_registry, ZEND_STRL("pcntl")))
     {
         REGISTER_LONG_CONSTANT("SIGHUP", (long) SIGHUP, CONST_CS | CONST_PERSISTENT);
         REGISTER_LONG_CONSTANT("SIGINT", (long) SIGINT, CONST_CS | CONST_PERSISTENT);
@@ -264,19 +263,19 @@ static PHP_METHOD(swoole_process, __construct)
     //only cli env
     if (!SWOOLE_G(cli))
     {
-        swoole_php_fatal_error(E_ERROR, "swoole_process only can be used in PHP CLI mode.");
+        swoole_php_fatal_error(E_ERROR, "swoole_process only can be used in PHP CLI mode");
         RETURN_FALSE;
     }
 
     if (SwooleG.serv && SwooleG.serv->gs->start == 1 && swIsMaster())
     {
-        swoole_php_fatal_error(E_ERROR, "swoole_process can't be used in master process.");
+        swoole_php_fatal_error(E_ERROR, "swoole_process can't be used in master process");
         RETURN_FALSE;
     }
 
     if (SwooleAIO.init)
     {
-        swoole_php_fatal_error(E_ERROR, "unable to create process with async-io threads.");
+        swoole_php_fatal_error(E_ERROR, "unable to create process with async-io threads");
         RETURN_FALSE;
     }
 
@@ -330,7 +329,7 @@ static PHP_METHOD(swoole_process, __construct)
         process->pipe_worker = _pipe->getFd(_pipe, SW_PIPE_WORKER);
         process->pipe = process->pipe_master;
 
-        zend_update_property_long(swoole_process_ce_ptr, getThis(), ZEND_STRL("pipe"), process->pipe_master);
+        zend_update_property_long(swoole_process_ce, getThis(), ZEND_STRL("pipe"), process->pipe_master);
     }
 
     proc->pipe_type = pipe_type;
@@ -344,7 +343,7 @@ static PHP_METHOD(swoole_process, __construct)
 
 static PHP_METHOD(swoole_process, __destruct)
 {
-    SW_PREVENT_USER_DESTRUCT;
+    SW_PREVENT_USER_DESTRUCT();
 
     swWorker *process = (swWorker *) swoole_get_object(getThis());
     swoole_set_object(getThis(), NULL);
@@ -359,13 +358,16 @@ static PHP_METHOD(swoole_process, __destruct)
         efree(process->queue);
     }
     php::process *proc = (php::process *) process->ptr2;
-    sw_fci_cache_discard(&proc->fci_cache);
-    if (proc->zsocket)
+    if (proc)
     {
-        OBJ_RELEASE(proc->zsocket);
+        sw_fci_cache_discard(&proc->fci_cache);
+        if (proc->zsocket)
+        {
+            OBJ_RELEASE(proc->zsocket);
+        }
+        efree(proc);
+        efree(process);
     }
-    efree(proc);
-    efree(process);
 }
 
 static PHP_METHOD(swoole_process, wait)
@@ -432,8 +434,8 @@ static PHP_METHOD(swoole_process, useQueue)
     }
     process->queue = queue;
     process->ipc_mode = mode;
-    zend_update_property_long(swoole_process_ce_ptr, getThis(), ZEND_STRL("msgQueueId"), queue->msg_id);
-    zend_update_property_long(swoole_process_ce_ptr, getThis(), ZEND_STRL("msgQueueKey"), msgkey);
+    zend_update_property_long(swoole_process_ce, getThis(), ZEND_STRL("msgQueueId"), queue->msg_id);
+    zend_update_property_long(swoole_process_ce, getThis(), ZEND_STRL("msgQueueKey"), msgkey);
     RETURN_TRUE;
 }
 
@@ -442,7 +444,7 @@ static PHP_METHOD(swoole_process, statQueue)
     swWorker *process = (swWorker *) swoole_get_object(getThis());
     if (!process->queue)
     {
-        swoole_php_fatal_error(E_WARNING, "no queue, can't get stats of the queue.");
+        swoole_php_fatal_error(E_WARNING, "no queue, can't get stats of the queue");
         RETURN_FALSE;
     }
 
@@ -490,7 +492,7 @@ static PHP_METHOD(swoole_process, kill)
     {
         if (!(sig == 0 && errno == ESRCH))
         {
-            swoole_php_error(E_WARNING, "swKill(%d, %d) failed. Error: %s[%d]", (int) pid, (int) sig, strerror(errno), errno);
+            swoole_php_sys_error(E_WARNING, "swKill(%d, %d) failed", (int) pid, (int) sig);
         }
         RETURN_FALSE;
     }
@@ -509,13 +511,13 @@ static PHP_METHOD(swoole_process, signal)
 
     if (!SWOOLE_G(cli))
     {
-        swoole_php_fatal_error(E_ERROR, "cannot use swoole_process::signal here.");
+        swoole_php_fatal_error(E_ERROR, "cannot use swoole_process::signal here");
         RETURN_FALSE;
     }
 
     if (signo < 0 || signo >= SW_SIGNO_MAX)
     {
-        swoole_php_fatal_error(E_WARNING, "invalid signal number [%ld].", signo);
+        swoole_php_fatal_error(E_WARNING, "invalid signal number [%ld]", signo);
         RETURN_FALSE;
     }
 
@@ -524,7 +526,7 @@ static PHP_METHOD(swoole_process, signal)
 
     if (handler && handler != php_swoole_onSignal)
     {
-        swoole_php_fatal_error(E_WARNING, "This signal [%ld] processor has been registered by the system.", signo);
+        swoole_php_fatal_error(E_WARNING, "This signal [%ld] processor has been registered by the system", signo);
         RETURN_FALSE
     }
 
@@ -541,7 +543,7 @@ static PHP_METHOD(swoole_process, signal)
         }
         else
         {
-            swoole_php_error(E_WARNING, "no callback.");
+            swoole_php_error(E_WARNING, "no callback");
             RETURN_FALSE;
         }
     }
@@ -604,13 +606,13 @@ static PHP_METHOD(swoole_process, alarm)
 
     if (!SWOOLE_G(cli))
     {
-        swoole_php_fatal_error(E_ERROR, "cannot use swoole_process::alarm here.");
+        swoole_php_fatal_error(E_ERROR, "cannot use swoole_process::alarm here");
         RETURN_FALSE;
     }
 
     if (SwooleG.timer.initialized != 0)
     {
-        swoole_php_fatal_error(E_WARNING, "cannot use both 'timer' and 'alarm' at the same time.");
+        swoole_php_fatal_error(E_WARNING, "cannot use both 'timer' and 'alarm' at the same time");
         RETURN_FALSE;
     }
 
@@ -637,7 +639,7 @@ static PHP_METHOD(swoole_process, alarm)
 
     if (setitimer(type, &timer_set, NULL) < 0)
     {
-        swoole_php_error(E_WARNING, "setitimer() failed. Error: %s[%d]", strerror(errno), errno);
+        swoole_php_sys_error(E_WARNING, "setitimer() failed");
         RETURN_FALSE;
     }
 
@@ -679,7 +681,7 @@ zend_bool php_swoole_signal_isset_handler(int signo)
 {
     if (signo < 0 || signo >= SW_SIGNO_MAX)
     {
-        swoole_php_fatal_error(E_WARNING, "invalid signal number [%d].", signo);
+        swoole_php_fatal_error(E_WARNING, "invalid signal number [%d]", signo);
         return SW_FALSE;
     }
     return signal_callback[signo] != NULL;
@@ -712,7 +714,7 @@ int php_swoole_process_start(swWorker *process, zval *zobject)
     {
         if (dup2(process->pipe, STDIN_FILENO) < 0)
         {
-            swoole_php_fatal_error(E_WARNING, "dup2() failed. Error: %s[%d]", strerror(errno), errno);
+            swoole_php_sys_error(E_WARNING, "dup2() failed");
         }
     }
 
@@ -720,7 +722,7 @@ int php_swoole_process_start(swWorker *process, zval *zobject)
     {
         if (dup2(process->pipe, STDOUT_FILENO) < 0)
         {
-            swoole_php_fatal_error(E_WARNING, "dup2() failed. Error: %s[%d]", strerror(errno), errno);
+            swoole_php_sys_error(E_WARNING, "dup2() failed");
         }
     }
 
@@ -728,7 +730,7 @@ int php_swoole_process_start(swWorker *process, zval *zobject)
     {
         if (dup2(process->pipe, STDERR_FILENO) < 0)
         {
-            swoole_php_fatal_error(E_WARNING, "dup2() failed. Error: %s[%d]", strerror(errno), errno);
+            swoole_php_sys_error(E_WARNING, "dup2() failed");
         }
     }
 
@@ -736,8 +738,8 @@ int php_swoole_process_start(swWorker *process, zval *zobject)
     SwooleWG.id = process->id;
     SwooleWG.worker = process;
 
-    zend_update_property_long(swoole_process_ce_ptr, zobject, ZEND_STRL("pid"), process->pid);
-    zend_update_property_long(swoole_process_ce_ptr, zobject, ZEND_STRL("pipe"), process->pipe_worker);
+    zend_update_property_long(swoole_process_ce, zobject, ZEND_STRL("pid"), process->pid);
+    zend_update_property_long(swoole_process_ce, zobject, ZEND_STRL("pipe"), process->pipe_worker);
 
     zval args[1];
     zval *retval = NULL;
@@ -750,7 +752,7 @@ int php_swoole_process_start(swWorker *process, zval *zobject)
     {
         if (PHPCoroutine::create(&proc->fci_cache, 1, args) < 0)
         {
-            swoole_php_error(E_WARNING, "create process coroutine error.");
+            swoole_php_error(E_WARNING, "create process coroutine error");
             return SW_ERR;
         }
     }
@@ -759,7 +761,7 @@ int php_swoole_process_start(swWorker *process, zval *zobject)
         zval _retval, *retval = &_retval;
         if (sw_call_user_function_fast_ex(NULL, &proc->fci_cache, retval, 1, args) == FAILURE)
         {
-            swoole_php_error(E_WARNING, "callback function error.");
+            swoole_php_error(E_WARNING, "callback function error");
         }
         zval_ptr_dtor(retval);
     }
@@ -789,21 +791,21 @@ static PHP_METHOD(swoole_process, start)
 
     if (swKill(process->pid, 0) == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "process has already been started.");
+        swoole_php_fatal_error(E_WARNING, "process has already been started");
         RETURN_FALSE;
     }
 
     pid_t pid = swoole_fork();
     if (pid < 0)
     {
-        swoole_php_fatal_error(E_WARNING, "fork() failed. Error: %s[%d]", strerror(errno), errno);
+        swoole_php_sys_error(E_WARNING, "fork() failed");
         RETURN_FALSE;
     }
     else if (pid > 0)
     {
         process->pid = pid;
         process->child_process = 0;
-        zend_update_property_long(swoole_server_ce_ptr, getThis(), ZEND_STRL("pid"), process->pid);
+        zend_update_property_long(swoole_server_ce, getThis(), ZEND_STRL("pid"), process->pid);
         RETURN_LONG(pid);
     }
     else
@@ -832,7 +834,7 @@ static PHP_METHOD(swoole_process, read)
 
     if (process->pipe == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "no pipe, cannot read from pipe.");
+        swoole_php_fatal_error(E_WARNING, "no pipe, cannot read from pipe");
         RETURN_FALSE;
     }
 
@@ -843,7 +845,7 @@ static PHP_METHOD(swoole_process, read)
         efree(buf);
         if (errno != EINTR)
         {
-            swoole_php_error(E_WARNING, "read() failed. Error: %s[%d]", strerror(errno), errno);
+            swoole_php_sys_error(E_WARNING, "read() failed");
         }
         RETURN_FALSE;
     }
@@ -864,14 +866,14 @@ static PHP_METHOD(swoole_process, write)
 
     if (data_len < 1)
     {
-        swoole_php_fatal_error(E_WARNING, "the data to send is empty.");
+        swoole_php_fatal_error(E_WARNING, "the data to send is empty");
         RETURN_FALSE;
     }
 
     swWorker *process = (swWorker *) swoole_get_object(getThis());
     if (process->pipe == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "no pipe, cannot write into pipe.");
+        swoole_php_fatal_error(E_WARNING, "no pipe, cannot write into pipe");
         RETURN_FALSE;
     }
 
@@ -897,7 +899,7 @@ static PHP_METHOD(swoole_process, write)
 
     if (ret < 0)
     {
-        swoole_php_error(E_WARNING, "write() failed. Error: %s[%d]", strerror(errno), errno);
+        swoole_php_sys_error(E_WARNING, "write() failed");
         RETURN_FALSE;
     }
     ZVAL_LONG(return_value, ret);
@@ -911,7 +913,7 @@ static PHP_METHOD(swoole_process, exportSocket)
     swWorker *process = (swWorker *) swoole_get_object(getThis());
     if (process->pipe == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "no pipe, cannot export stream.");
+        swoole_php_fatal_error(E_WARNING, "no pipe, cannot export stream");
         RETURN_FALSE;
     }
     php::process *proc = (php::process *) process->ptr2;
@@ -945,12 +947,12 @@ static PHP_METHOD(swoole_process, push)
 
     if (length <= 0)
     {
-        swoole_php_fatal_error(E_WARNING, "the data to push is empty.");
+        swoole_php_fatal_error(E_WARNING, "the data to push is empty");
         RETURN_FALSE;
     }
     else if (length >= sizeof(message.data))
     {
-        swoole_php_fatal_error(E_WARNING, "the data to push is too big.");
+        swoole_php_fatal_error(E_WARNING, "the data to push is too big");
         RETURN_FALSE;
     }
 
@@ -1029,7 +1031,7 @@ static PHP_METHOD(swoole_process, exec)
 
     if (execfile_len < 1)
     {
-        swoole_php_fatal_error(E_WARNING, "exec file name is empty.");
+        swoole_php_fatal_error(E_WARNING, "exec file name is empty");
         RETURN_FALSE;
     }
 
@@ -1050,7 +1052,7 @@ static PHP_METHOD(swoole_process, exec)
 
     if (execv(execfile, exec_args) < 0)
     {
-        swoole_php_fatal_error(E_WARNING, "execv(%s) failed. Error: %s[%d]", execfile, strerror(errno), errno);
+        swoole_php_sys_error(E_WARNING, "execv(%s) failed", execfile);
         RETURN_FALSE;
     }
     else
@@ -1109,7 +1111,7 @@ static PHP_METHOD(swoole_process, setaffinity)
     if (sched_setaffinity(getpid(), sizeof(cpu_set), &cpu_set) < 0)
 #endif
     {
-        swoole_php_sys_error(E_WARNING, "sched_setaffinity() failed.");
+        swoole_php_sys_error(E_WARNING, "sched_setaffinity() failed");
         RETURN_FALSE;
     }
     RETURN_TRUE;
@@ -1129,7 +1131,7 @@ static PHP_METHOD(swoole_process, exit)
 
     if (getpid() != process->pid)
     {
-        swoole_php_fatal_error(E_WARNING, "not current process.");
+        swoole_php_fatal_error(E_WARNING, "not current process");
         RETURN_FALSE;
     }
 
@@ -1164,7 +1166,7 @@ static PHP_METHOD(swoole_process, close)
     swWorker *process = (swWorker *) swoole_get_object(getThis());
     if (process->pipe == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "no pipe, cannot close the pipe.");
+        swoole_php_fatal_error(E_WARNING, "no pipe, cannot close the pipe");
         RETURN_FALSE;
     }
 
@@ -1183,7 +1185,7 @@ static PHP_METHOD(swoole_process, close)
     }
     if (ret < 0)
     {
-        swoole_php_fatal_error(E_WARNING, "close() failed. Error: %s[%d]", strerror(errno), errno);
+        swoole_php_sys_error(E_WARNING, "close() failed");
         RETURN_FALSE;
     }
     if (which == 0)
@@ -1206,7 +1208,7 @@ static PHP_METHOD(swoole_process, setTimeout)
     swWorker *process = (swWorker *) swoole_get_object(getThis());
     if (process->pipe == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "no pipe, cannot setTimeout the pipe.");
+        swoole_php_fatal_error(E_WARNING, "no pipe, cannot setTimeout the pipe");
         RETURN_FALSE;
     }
     SW_CHECK_RETURN(swSocket_set_timeout(process->pipe, seconds));
@@ -1223,7 +1225,7 @@ static PHP_METHOD(swoole_process, setBlocking)
     swWorker *process = (swWorker *) swoole_get_object(getThis());
     if (process->pipe == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "no pipe, cannot setBlocking the pipe.");
+        swoole_php_fatal_error(E_WARNING, "no pipe, cannot setBlocking the pipe");
         RETURN_FALSE;
     }
     if (blocking)
